summaryrefslogtreecommitdiffstats
path: root/kshowmail/kcmconfigs/configactions.h
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-07-24 15:59:03 -0500
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-07-24 15:59:03 -0500
commit9c02dbb59ce57c68dc177d9294b980bf114a3e11 (patch)
treeb1b40423c9be9a42a97cd0e8f3af3139aefb6fa0 /kshowmail/kcmconfigs/configactions.h
parent0b875800e452c97b1a3f25aba5f029a8c33a4b93 (diff)
downloadkshowmail-9c02dbb59ce57c68dc177d9294b980bf114a3e11.tar.gz
kshowmail-9c02dbb59ce57c68dc177d9294b980bf114a3e11.zip
Update to TDE R14 API
Diffstat (limited to 'kshowmail/kcmconfigs/configactions.h')
-rw-r--r--kshowmail/kcmconfigs/configactions.h44
1 files changed, 22 insertions, 22 deletions
diff --git a/kshowmail/kcmconfigs/configactions.h b/kshowmail/kcmconfigs/configactions.h
index 901984f..927f121 100644
--- a/kshowmail/kcmconfigs/configactions.h
+++ b/kshowmail/kcmconfigs/configactions.h
@@ -15,22 +15,22 @@
#include <string.h>
//QT headers
-#include <qlayout.h>
-#include <qgroupbox.h>
-#include <qcheckbox.h>
-#include <qtooltip.h>
+#include <ntqlayout.h>
+#include <ntqgroupbox.h>
+#include <ntqcheckbox.h>
+#include <ntqtooltip.h>
//KDE headers
-#include <kcmodule.h>
+#include <tdecmodule.h>
#include <kgenericfactory.h>
#include <kpushbutton.h>
#include <klineedit.h>
#include <kdebug.h>
-#include <kapplication.h>
-#include <kfiledialog.h>
+#include <tdeapplication.h>
+#include <tdefiledialog.h>
#include <kaudioplayer.h>
#include <kprocess.h>
-#include <kmessagebox.h>
+#include <tdemessagebox.h>
#include <kstandarddirs.h>
//kshowmail headers
@@ -41,7 +41,7 @@
*
* @author Ulrich Weigelt <ulrich.weigelt@gmx.de>
*/
-class ConfigActions : public KCModule
+class ConfigActions : public TDECModule
{
Q_OBJECT
@@ -49,7 +49,7 @@ Q_OBJECT
/**
* Generic Constructor
*/
- ConfigActions( QWidget *parent = 0, const char *name = 0, const QStringList &args = QStringList() );
+ ConfigActions( TQWidget *parent = 0, const char *name = 0, const TQStringList &args = TQStringList() );
/**
* Destructor
@@ -57,21 +57,21 @@ Q_OBJECT
~ConfigActions();
/**
* Overloaded method of KCModule.
* Sets the user interface elements to reflect the current settings stored in the
* config file.
*/
virtual void load();
/**
* Overloaded method of KCModule.
* Sets the user interface elements to default values.
* This method is called when the user clicks the "Default" button.
*/
virtual void defaults();
/**
* Overloaded method of KCModule.
* Stores the config information as shown in the user interface in the
* config file.
* Is called when the user clicks "Apply" or "Ok".
@@ -83,32 +83,32 @@ Q_OBJECT
/**
* Connector to the configuration file
*/
- KConfig* config;
+ TDEConfig* config;
/**
* Check box to select whether an alert message will be shown if a new mail is arrived.
*/
- QCheckBox* chkNewMailsAlertWindow;
+ TQCheckBox* chkNewMailsAlertWindow;
/**
* Check box to select whether the main window will be shown if a new mail is arrived.
*/
- QCheckBox* chkNewMailsMainWindow;
+ TQCheckBox* chkNewMailsMainWindow;
/**
* Check box to select whether the system beep will be played if a new mail is arrived.
*/
- QCheckBox* chkNewMailsBeep;
+ TQCheckBox* chkNewMailsBeep;
/**
* Check box to select whether a sound will be played if a new mail is arrived.
*/
- QCheckBox* chkNewMailsSound;
+ TQCheckBox* chkNewMailsSound;
/**
* Check box to select whether a command will be executed if a new mail is arrived.
*/
- QCheckBox* chkNewMailsCommand;
+ TQCheckBox* chkNewMailsCommand;
/**
* Button to test the sound which will be played if a new mail is arrived.
@@ -143,12 +143,12 @@ Q_OBJECT
/**
* Check box to select whether the main window will be minimized if no new mail is arrived.
*/
- QCheckBox* chkNoNewMailsMinimize;
+ TQCheckBox* chkNoNewMailsMinimize;
/**
* Check box to select whether the application will be terminated if no new mail is arrived.
*/
- QCheckBox* chkNoNewMailsTerminate;
+ TQCheckBox* chkNoNewMailsTerminate;
private slots:
@@ -194,7 +194,7 @@ Q_OBJECT
/**
* Connected with the configuration items.
* Calls the slot changed() of KCModule to notify the dialog about the change.
*/
void slotChanged();
};
@@ -57,21 +57,21 @@ Q_OBJECT
~ConfigActions();
/**
- * Overloaded method of KCModule.
+ * Overloaded method of TDECModule.
* Sets the user interface elements to reflect the current settings stored in the
* config file.
@@ -57,21 +57,21 @@ Q_OBJECT
virtual void load();
/**
- * Overloaded method of KCModule.
+ * Overloaded method of TDECModule.
* Sets the user interface elements to default values.
* This method is called when the user clicks the "Default" button.
@@ -57,21 +57,21 @@ Q_OBJECT
virtual void defaults();
/**
- * Overloaded method of KCModule.
+ * Overloaded method of TDECModule.
* Stores the config information as shown in the user interface in the
* config file.
@@ -194,7 +194,7 @@ Q_OBJECT
/**
* Connected with the configuration items.
- * Calls the slot changed() of KCModule to notify the dialog about the change.
+ * Calls the slot changed() of TDECModule to notify the dialog about the change.
*/
void slotChanged();